Class: Google::Apis::DfareportingV3_4::ConversionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

The original conversion that was inserted or updated and whether there were any errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversionStatus

Returns a new instance of ConversionStatus.



2625
2626
2627
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 2625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionGoogle::Apis::DfareportingV3_4::Conversion

A Conversion represents when a user successfully performs a desired action after seeing an ad. Corresponds to the JSON property conversion



2612
2613
2614
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 2612

def conversion
  @conversion
end

#errorsArray<Google::Apis::DfareportingV3_4::ConversionError>

A list of errors related to this conversion. Corresponds to the JSON property errors



2617
2618
2619
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 2617

def errors
  @errors
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#conversionStatus". Corresponds to the JSON property kind

Returns:

  • (String)


2623
2624
2625
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 2623

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2630
2631
2632
2633
2634
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 2630

def update!(**args)
  @conversion = args[:conversion] if args.key?(:conversion)
  @errors = args[:errors] if args.key?(:errors)
  @kind = args[:kind] if args.key?(:kind)
end