Class: Google::Apis::DfareportingV3_4::CreativeField
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::CreativeField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Contains properties of a creative field.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
Account ID of this creative field.
-
#advertiser_id ⇒ Fixnum
Advertiser ID of this creative field.
-
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV3_4::DimensionValue
Represents a DimensionValue resource.
-
#id ⇒ Fixnum
ID of this creative field.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#name ⇒ String
Name of this creative field.
-
#subaccount_id ⇒ Fixnum
Subaccount ID of this creative field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeField
constructor
A new instance of CreativeField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeField
Returns a new instance of CreativeField.
4218 4219 4220 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
Account ID of this creative field. This is a read-only field that can be left
blank.
Corresponds to the JSON property accountId
4183 4184 4185 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4183 def account_id @account_id end |
#advertiser_id ⇒ Fixnum
Advertiser ID of this creative field. This is a required field on insertion.
Corresponds to the JSON property advertiserId
4188 4189 4190 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4188 def advertiser_id @advertiser_id end |
#advertiser_id_dimension_value ⇒ Google::Apis::DfareportingV3_4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property advertiserIdDimensionValue
4193 4194 4195 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4193 def advertiser_id_dimension_value @advertiser_id_dimension_value end |
#id ⇒ Fixnum
ID of this creative field. This is a read-only, auto-generated field.
Corresponds to the JSON property id
4198 4199 4200 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4198 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#creativeField".
Corresponds to the JSON property kind
4204 4205 4206 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4204 def kind @kind end |
#name ⇒ String
Name of this creative field. This is a required field and must be less than
256 characters long and unique among creative fields of the same advertiser.
Corresponds to the JSON property name
4210 4211 4212 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4210 def name @name end |
#subaccount_id ⇒ Fixnum
Subaccount ID of this creative field. This is a read-only field that can be
left blank.
Corresponds to the JSON property subaccountId
4216 4217 4218 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4216 def subaccount_id @subaccount_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4223 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @advertiser_id_dimension_value = args[:advertiser_id_dimension_value] if args.key?(:advertiser_id_dimension_value) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id) end |