Class: Google::Apis::DfareportingV3_4::CustomEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Experimental feature (no support provided) A custom event represents a third party impression, a third party click, an annotation on a first party impression, or an annotation on a first party click.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomEvent

Returns a new instance of CustomEvent.



4698
4699
4700
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotate_click_eventGoogle::Apis::DfareportingV3_4::CustomEventClickAnnotation

Annotate a click event. Corresponds to the JSON property annotateClickEvent



4651
4652
4653
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4651

def annotate_click_event
  @annotate_click_event
end

#annotate_impression_eventGoogle::Apis::DfareportingV3_4::CustomEventImpressionAnnotation

Annotate an impression. Corresponds to the JSON property annotateImpressionEvent



4656
4657
4658
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4656

def annotate_impression_event
  @annotate_impression_event
end

#custom_variablesArray<Google::Apis::DfareportingV3_4::CustomVariable>

Custom variables associated with the event. Corresponds to the JSON property customVariables



4661
4662
4663
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4661

def custom_variables
  @custom_variables
end

#event_typeString

The type of event. If INSERT, the fields in insertEvent need to be populated. If ANNOTATE, the fields in either annotateClickEvent or annotateImpressionEvent need to be populated. Corresponds to the JSON property eventType

Returns:

  • (String)


4668
4669
4670
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4668

def event_type
  @event_type
end

#floodlight_configuration_idFixnum

Floodlight configuration ID of the advertiser the event is linked to. This is a required field. Corresponds to the JSON property floodlightConfigurationId

Returns:

  • (Fixnum)


4674
4675
4676
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4674

def floodlight_configuration_id
  @floodlight_configuration_id
end

#insert_eventGoogle::Apis::DfareportingV3_4::CustomEventInsert

Custom event to be inserted. Corresponds to the JSON property insertEvent



4679
4680
4681
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4679

def insert_event
  @insert_event
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customEvent". Corresponds to the JSON property kind

Returns:

  • (String)


4685
4686
4687
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4685

def kind
  @kind
end

#ordinalString

The ordinal of this custom event. This is a required field. Corresponds to the JSON property ordinal

Returns:

  • (String)


4690
4691
4692
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4690

def ordinal
  @ordinal
end

#timestamp_microsFixnum

The timestamp of this custom event, in Unix epoch micros. This is a required field. Corresponds to the JSON property timestampMicros

Returns:

  • (Fixnum)


4696
4697
4698
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4696

def timestamp_micros
  @timestamp_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4703

def update!(**args)
  @annotate_click_event = args[:annotate_click_event] if args.key?(:annotate_click_event)
  @annotate_impression_event = args[:annotate_impression_event] if args.key?(:annotate_impression_event)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @event_type = args[:event_type] if args.key?(:event_type)
  @floodlight_configuration_id = args[:floodlight_configuration_id] if args.key?(:floodlight_configuration_id)
  @insert_event = args[:insert_event] if args.key?(:insert_event)
  @kind = args[:kind] if args.key?(:kind)
  @ordinal = args[:ordinal] if args.key?(:ordinal)
  @timestamp_micros = args[:timestamp_micros] if args.key?(:timestamp_micros)
end