Class: Google::Apis::DfareportingV3_4::CustomEventStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

The original custom event that was inserted and whether there were any errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomEventStatus

Returns a new instance of CustomEventStatus.



4878
4879
4880
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_eventGoogle::Apis::DfareportingV3_4::CustomEvent

Experimental feature (no support provided) A custom event represents a third party impression, a third party click, an annotation on a first party impression, or an annotation on a first party click. Corresponds to the JSON property customEvent



4865
4866
4867
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4865

def custom_event
  @custom_event
end

#errorsArray<Google::Apis::DfareportingV3_4::CustomEventError>

A list of errors related to this custom event. Corresponds to the JSON property errors



4870
4871
4872
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4870

def errors
  @errors
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customEventStatus". Corresponds to the JSON property kind

Returns:

  • (String)


4876
4877
4878
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4876

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4883
4884
4885
4886
4887
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4883

def update!(**args)
  @custom_event = args[:custom_event] if args.key?(:custom_event)
  @errors = args[:errors] if args.key?(:errors)
  @kind = args[:kind] if args.key?(:kind)
end