Class: Google::Apis::DfareportingV3_4::CustomEventsBatchInsertResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Insert Custom Events Response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomEventsBatchInsertResponse

Returns a new instance of CustomEventsBatchInsertResponse.



4938
4939
4940
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_failuresBoolean Also known as: has_failures?

Indicates that some or all custom events failed to insert. Corresponds to the JSON property hasFailures

Returns:

  • (Boolean)


4923
4924
4925
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4923

def has_failures
  @has_failures
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#customEventsBatchInsertResponse". Corresponds to the JSON property kind

Returns:

  • (String)


4930
4931
4932
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4930

def kind
  @kind
end

#statusArray<Google::Apis::DfareportingV3_4::CustomEventStatus>

The insert status of each custom event. Statuses are returned in the same order that conversions are inserted. Corresponds to the JSON property status



4936
4937
4938
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4936

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4943
4944
4945
4946
4947
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4943

def update!(**args)
  @has_failures = args[:has_failures] if args.key?(:has_failures)
  @kind = args[:kind] if args.key?(:kind)
  @status = args[:status] if args.key?(:status)
end