Class: Google::Apis::DfareportingV3_4::CustomFloodlightVariable
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::CustomFloodlightVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
A custom floodlight variable. This field may only be used when calling batchinsert; it is not supported by batchupdate.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#type ⇒ String
The type of custom floodlight variable to supply a value for.
-
#value ⇒ String
The value of the custom floodlight variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomFloodlightVariable
constructor
A new instance of CustomFloodlightVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomFloodlightVariable
Returns a new instance of CustomFloodlightVariable.
4973 4974 4975 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#customFloodlightVariable".
Corresponds to the JSON property kind
4959 4960 4961 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4959 def kind @kind end |
#type ⇒ String
The type of custom floodlight variable to supply a value for. These map to the
"u[1-20]=" in the tags.
Corresponds to the JSON property type
4965 4966 4967 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4965 def type @type end |
#value ⇒ String
The value of the custom floodlight variable. The length of string must not
exceed 100 characters.
Corresponds to the JSON property value
4971 4972 4973 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4971 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4978 4979 4980 4981 4982 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 4978 def update!(**args) @kind = args[:kind] if args.key?(:kind) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |