Class: Google::Apis::DfareportingV3_4::DimensionValueRequest
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::DimensionValueRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Represents a DimensionValuesRequest.
Instance Attribute Summary collapse
-
#dimension_name ⇒ String
The name of the dimension for which values should be requested.
-
#end_date ⇒ Date
Corresponds to the JSON property
endDate. -
#filters ⇒ Array<Google::Apis::DfareportingV3_4::DimensionFilter>
The list of filters by which to filter values.
-
#kind ⇒ String
The kind of request this is, in this case dfareporting#dimensionValueRequest .
-
#start_date ⇒ Date
Corresponds to the JSON property
startDate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DimensionValueRequest
constructor
A new instance of DimensionValueRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DimensionValueRequest
Returns a new instance of DimensionValueRequest.
5589 5590 5591 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_name ⇒ String
The name of the dimension for which values should be requested.
Corresponds to the JSON property dimensionName
5567 5568 5569 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5567 def dimension_name @dimension_name end |
#end_date ⇒ Date
Corresponds to the JSON property endDate
5572 5573 5574 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5572 def end_date @end_date end |
#filters ⇒ Array<Google::Apis::DfareportingV3_4::DimensionFilter>
The list of filters by which to filter values. The filters are ANDed.
Corresponds to the JSON property filters
5577 5578 5579 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5577 def filters @filters end |
#kind ⇒ String
The kind of request this is, in this case dfareporting#dimensionValueRequest .
Corresponds to the JSON property kind
5582 5583 5584 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5582 def kind @kind end |
#start_date ⇒ Date
Corresponds to the JSON property startDate
5587 5588 5589 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5587 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5594 5595 5596 5597 5598 5599 5600 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5594 def update!(**args) @dimension_name = args[:dimension_name] if args.key?(:dimension_name) @end_date = args[:end_date] if args.key?(:end_date) @filters = args[:filters] if args.key?(:filters) @kind = args[:kind] if args.key?(:kind) @start_date = args[:start_date] if args.key?(:start_date) end |