Class: Google::Apis::DfareportingV3_4::DisjunctiveMatchStatement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Represents a Disjunctive Match Statement resource, which is a conjunction (and) of disjunctive (or) boolean statements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisjunctiveMatchStatement

Returns a new instance of DisjunctiveMatchStatement.



5758
5759
5760
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_filtersArray<Google::Apis::DfareportingV3_4::EventFilter>

The event filters contained within this disjunctive match statement. Corresponds to the JSON property eventFilters



5750
5751
5752
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5750

def event_filters
  @event_filters
end

#kindString

The kind of resource this is, in this case dfareporting# disjunctiveMatchStatement. Corresponds to the JSON property kind

Returns:

  • (String)


5756
5757
5758
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5756

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5763
5764
5765
5766
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 5763

def update!(**args)
  @event_filters = args[:event_filters] if args.key?(:event_filters)
  @kind = args[:kind] if args.key?(:kind)
end