Class: Google::Apis::DfareportingV3_4::File::Urls

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

The URLs where the completed report file can be downloaded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Urls

Returns a new instance of Urls.



6189
6190
6191
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 6189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_urlString

The URL for downloading the report data through the API. Corresponds to the JSON property apiUrl

Returns:

  • (String)


6182
6183
6184
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 6182

def api_url
  @api_url
end

#browser_urlString

The URL for downloading the report data through a browser. Corresponds to the JSON property browserUrl

Returns:

  • (String)


6187
6188
6189
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 6187

def browser_url
  @browser_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6194
6195
6196
6197
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 6194

def update!(**args)
  @api_url = args[:api_url] if args.key?(:api_url)
  @browser_url = args[:browser_url] if args.key?(:browser_url)
end