Class: Google::Apis::DfareportingV3_4::FsCommand
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::FsCommand
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
FsCommand.
Instance Attribute Summary collapse
-
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is DISTANCE_FROM_TOP_LEFT_CORNER.
-
#position_option ⇒ String
Position in the browser where the window will open.
-
#top ⇒ Fixnum
Distance from the top of the browser.
-
#window_height ⇒ Fixnum
Height of the window.
-
#window_width ⇒ Fixnum
Width of the window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FsCommand
constructor
A new instance of FsCommand.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FsCommand
Returns a new instance of FsCommand.
7036 7037 7038 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left ⇒ Fixnum
Distance from the left of the browser.Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property left
7013 7014 7015 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7013 def left @left end |
#position_option ⇒ String
Position in the browser where the window will open.
Corresponds to the JSON property positionOption
7018 7019 7020 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7018 def position_option @position_option end |
#top ⇒ Fixnum
Distance from the top of the browser. Applicable when positionOption is
DISTANCE_FROM_TOP_LEFT_CORNER.
Corresponds to the JSON property top
7024 7025 7026 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7024 def top @top end |
#window_height ⇒ Fixnum
Height of the window.
Corresponds to the JSON property windowHeight
7029 7030 7031 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7029 def window_height @window_height end |
#window_width ⇒ Fixnum
Width of the window.
Corresponds to the JSON property windowWidth
7034 7035 7036 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7034 def window_width @window_width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7041 7042 7043 7044 7045 7046 7047 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7041 def update!(**args) @left = args[:left] if args.key?(:left) @position_option = args[:position_option] if args.key?(:position_option) @top = args[:top] if args.key?(:top) @window_height = args[:window_height] if args.key?(:window_height) @window_width = args[:window_width] if args.key?(:window_width) end |