Class: Google::Apis::DfareportingV3_4::LookbackConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Lookback configuration settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookbackConfiguration

Returns a new instance of LookbackConfiguration.



7644
7645
7646
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#click_durationFixnum

Lookback window, in days, from the last time a given user clicked on one of your ads. If you enter 0, clicks will not be considered as triggering events for floodlight tracking. If you leave this field blank, the default value for your account will be used. Acceptable values are 0 to 90, inclusive. Corresponds to the JSON property clickDuration

Returns:

  • (Fixnum)


7634
7635
7636
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7634

def click_duration
  @click_duration
end

#post_impression_activities_durationFixnum

Lookback window, in days, from the last time a given user viewed one of your ads. If you enter 0, impressions will not be considered as triggering events for floodlight tracking. If you leave this field blank, the default value for your account will be used. Acceptable values are 0 to 90, inclusive. Corresponds to the JSON property postImpressionActivitiesDuration

Returns:

  • (Fixnum)


7642
7643
7644
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7642

def post_impression_activities_duration
  @post_impression_activities_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7649
7650
7651
7652
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 7649

def update!(**args)
  @click_duration = args[:click_duration] if args.key?(:click_duration)
  @post_impression_activities_duration = args[:post_impression_activities_duration] if args.key?(:post_impression_activities_duration)
end