Class: Google::Apis::DfareportingV3_4::OperatingSystemVersion
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::OperatingSystemVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Contains information about a particular version of an operating system that can be targeted by ads.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
ID of this operating system version.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#major_version ⇒ String
Major version (leftmost number) of this operating system version.
-
#minor_version ⇒ String
Minor version (number after the first dot) of this operating system version.
-
#name ⇒ String
Name of this operating system version.
-
#operating_system ⇒ Google::Apis::DfareportingV3_4::OperatingSystem
Contains information about an operating system that can be targeted by ads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperatingSystemVersion
constructor
A new instance of OperatingSystemVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperatingSystemVersion
Returns a new instance of OperatingSystemVersion.
8143 8144 8145 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
ID of this operating system version.
Corresponds to the JSON property id
8115 8116 8117 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8115 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#operatingSystemVersion".
Corresponds to the JSON property kind
8121 8122 8123 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8121 def kind @kind end |
#major_version ⇒ String
Major version (leftmost number) of this operating system version.
Corresponds to the JSON property majorVersion
8126 8127 8128 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8126 def major_version @major_version end |
#minor_version ⇒ String
Minor version (number after the first dot) of this operating system version.
Corresponds to the JSON property minorVersion
8131 8132 8133 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8131 def minor_version @minor_version end |
#name ⇒ String
Name of this operating system version.
Corresponds to the JSON property name
8136 8137 8138 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8136 def name @name end |
#operating_system ⇒ Google::Apis::DfareportingV3_4::OperatingSystem
Contains information about an operating system that can be targeted by ads.
Corresponds to the JSON property operatingSystem
8141 8142 8143 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8141 def @operating_system end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8148 8149 8150 8151 8152 8153 8154 8155 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8148 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @major_version = args[:major_version] if args.key?(:major_version) @minor_version = args[:minor_version] if args.key?(:minor_version) @name = args[:name] if args.key?(:name) @operating_system = args[:operating_system] if args.key?(:operating_system) end |