Class: Google::Apis::DfareportingV3_4::OptimizationActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Creative optimization activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OptimizationActivity

Returns a new instance of OptimizationActivity.



8231
8232
8233
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Floodlight activity ID of this optimization activity. This is a required field. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


8217
8218
8219
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8217

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_activity_id_dimension_valueGoogle::Apis::DfareportingV3_4::DimensionValue

Represents a DimensionValue resource. Corresponds to the JSON property floodlightActivityIdDimensionValue



8222
8223
8224
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8222

def floodlight_activity_id_dimension_value
  @floodlight_activity_id_dimension_value
end

#weightFixnum

Weight associated with this optimization. The weight assigned will be understood in proportion to the weights assigned to the other optimization activities. Value must be greater than or equal to 1. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


8229
8230
8231
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8229

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8236
8237
8238
8239
8240
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8236

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_activity_id_dimension_value = args[:floodlight_activity_id_dimension_value] if args.key?(:floodlight_activity_id_dimension_value)
  @weight = args[:weight] if args.key?(:weight)
end