Class: Google::Apis::DfareportingV3_4::OrderDocument

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Contains properties of a Planning order document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrderDocument

Returns a new instance of OrderDocument.



8517
8518
8519
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this order document. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


8430
8431
8432
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8430

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this order document. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8435
8436
8437
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8435

def advertiser_id
  @advertiser_id
end

#amended_order_document_idFixnum

The amended order document ID of this order document. An order document can be created by optionally amending another order document so that the change history can be preserved. Corresponds to the JSON property amendedOrderDocumentId

Returns:

  • (Fixnum)


8442
8443
8444
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8442

def amended_order_document_id
  @amended_order_document_id
end

#approved_by_user_profile_idsArray<Fixnum>

IDs of users who have approved this order document. Corresponds to the JSON property approvedByUserProfileIds

Returns:

  • (Array<Fixnum>)


8447
8448
8449
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8447

def 
  @approved_by_user_profile_ids
end

#cancelledBoolean Also known as: cancelled?

Whether this order document is cancelled. Corresponds to the JSON property cancelled

Returns:

  • (Boolean)


8452
8453
8454
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8452

def cancelled
  @cancelled
end

#created_infoGoogle::Apis::DfareportingV3_4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property createdInfo



8458
8459
8460
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8458

def created_info
  @created_info
end

#effective_dateDate

Corresponds to the JSON property effectiveDate

Returns:

  • (Date)


8463
8464
8465
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8463

def effective_date
  @effective_date
end

#idFixnum

ID of this order document. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8468
8469
8470
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8468

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#orderDocument". Corresponds to the JSON property kind

Returns:

  • (String)


8474
8475
8476
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8474

def kind
  @kind
end

#last_sent_recipientsArray<String>

List of email addresses that received the last sent document. Corresponds to the JSON property lastSentRecipients

Returns:

  • (Array<String>)


8479
8480
8481
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8479

def last_sent_recipients
  @last_sent_recipients
end

#last_sent_timeDateTime

Corresponds to the JSON property lastSentTime

Returns:

  • (DateTime)


8484
8485
8486
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8484

def last_sent_time
  @last_sent_time
end

#order_idFixnum

ID of the order from which this order document is created. Corresponds to the JSON property orderId

Returns:

  • (Fixnum)


8489
8490
8491
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8489

def order_id
  @order_id
end

#project_idFixnum

Project ID of this order document. Corresponds to the JSON property projectId

Returns:

  • (Fixnum)


8494
8495
8496
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8494

def project_id
  @project_id
end

#signedBoolean Also known as: signed?

Whether this order document has been signed. Corresponds to the JSON property signed

Returns:

  • (Boolean)


8499
8500
8501
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8499

def signed
  @signed
end

#subaccount_idFixnum

Subaccount ID of this order document. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


8505
8506
8507
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8505

def subaccount_id
  @subaccount_id
end

#titleString

Title of this order document. Corresponds to the JSON property title

Returns:

  • (String)


8510
8511
8512
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8510

def title
  @title
end

#typeString

Type of this order document Corresponds to the JSON property type

Returns:

  • (String)


8515
8516
8517
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8515

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8522
8523
8524
8525
8526
8527
8528
8529
8530
8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 8522

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @amended_order_document_id = args[:amended_order_document_id] if args.key?(:amended_order_document_id)
  @approved_by_user_profile_ids = args[:approved_by_user_profile_ids] if args.key?(:approved_by_user_profile_ids)
  @cancelled = args[:cancelled] if args.key?(:cancelled)
  @created_info = args[:created_info] if args.key?(:created_info)
  @effective_date = args[:effective_date] if args.key?(:effective_date)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_sent_recipients = args[:last_sent_recipients] if args.key?(:last_sent_recipients)
  @last_sent_time = args[:last_sent_time] if args.key?(:last_sent_time)
  @order_id = args[:order_id] if args.key?(:order_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @signed = args[:signed] if args.key?(:signed)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end