Class: Google::Apis::DfareportingV3_4::Project

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Contains properties of a Planning project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



9993
9994
9995
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this project. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


9882
9883
9884
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9882

def 
  @account_id
end

#advertiser_idFixnum

Advertiser ID of this project. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9887
9888
9889
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9887

def advertiser_id
  @advertiser_id
end

#audience_age_groupString

Audience age group of this project. Corresponds to the JSON property audienceAgeGroup

Returns:

  • (String)


9892
9893
9894
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9892

def audience_age_group
  @audience_age_group
end

#audience_genderString

Audience gender of this project. Corresponds to the JSON property audienceGender

Returns:

  • (String)


9897
9898
9899
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9897

def audience_gender
  @audience_gender
end

#budgetFixnum

Budget of this project in the currency specified by the current account. The value stored in this field represents only the non-fractional amount. For example, for USD, the smallest value that can be represented by this field is 1 US dollar. Corresponds to the JSON property budget

Returns:

  • (Fixnum)


9905
9906
9907
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9905

def budget
  @budget
end

#client_billing_codeString

Client billing code of this project. Corresponds to the JSON property clientBillingCode

Returns:

  • (String)


9910
9911
9912
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9910

def client_billing_code
  @client_billing_code
end

#client_nameString

Name of the project client. Corresponds to the JSON property clientName

Returns:

  • (String)


9915
9916
9917
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9915

def client_name
  @client_name
end

#end_dateDate

Corresponds to the JSON property endDate

Returns:

  • (Date)


9920
9921
9922
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9920

def end_date
  @end_date
end

#idFixnum

ID of this project. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9925
9926
9927
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9925

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#project". Corresponds to the JSON property kind

Returns:

  • (String)


9931
9932
9933
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9931

def kind
  @kind
end

#last_modified_infoGoogle::Apis::DfareportingV3_4::LastModifiedInfo

Modification timestamp. Corresponds to the JSON property lastModifiedInfo



9936
9937
9938
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9936

def last_modified_info
  @last_modified_info
end

#nameString

Name of this project. Corresponds to the JSON property name

Returns:

  • (String)


9941
9942
9943
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9941

def name
  @name
end

#overviewString

Overview of this project. Corresponds to the JSON property overview

Returns:

  • (String)


9946
9947
9948
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9946

def overview
  @overview
end

#start_dateDate

Corresponds to the JSON property startDate

Returns:

  • (Date)


9951
9952
9953
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9951

def start_date
  @start_date
end

#subaccount_idFixnum

Subaccount ID of this project. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


9956
9957
9958
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9956

def subaccount_id
  @subaccount_id
end

#target_clicksFixnum

Number of clicks that the advertiser is targeting. Corresponds to the JSON property targetClicks

Returns:

  • (Fixnum)


9961
9962
9963
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9961

def target_clicks
  @target_clicks
end

#target_conversionsFixnum

Number of conversions that the advertiser is targeting. Corresponds to the JSON property targetConversions

Returns:

  • (Fixnum)


9966
9967
9968
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9966

def target_conversions
  @target_conversions
end

#target_cpa_nanosFixnum

CPA that the advertiser is targeting. Corresponds to the JSON property targetCpaNanos

Returns:

  • (Fixnum)


9971
9972
9973
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9971

def target_cpa_nanos
  @target_cpa_nanos
end

#target_cpc_nanosFixnum

CPC that the advertiser is targeting. Corresponds to the JSON property targetCpcNanos

Returns:

  • (Fixnum)


9976
9977
9978
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9976

def target_cpc_nanos
  @target_cpc_nanos
end

#target_cpm_active_view_nanosFixnum

vCPM from Active View that the advertiser is targeting. Corresponds to the JSON property targetCpmActiveViewNanos

Returns:

  • (Fixnum)


9981
9982
9983
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9981

def target_cpm_active_view_nanos
  @target_cpm_active_view_nanos
end

#target_cpm_nanosFixnum

CPM that the advertiser is targeting. Corresponds to the JSON property targetCpmNanos

Returns:

  • (Fixnum)


9986
9987
9988
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9986

def target_cpm_nanos
  @target_cpm_nanos
end

#target_impressionsFixnum

Number of impressions that the advertiser is targeting. Corresponds to the JSON property targetImpressions

Returns:

  • (Fixnum)


9991
9992
9993
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9991

def target_impressions
  @target_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9998
9999
10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 9998

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @audience_age_group = args[:audience_age_group] if args.key?(:audience_age_group)
  @audience_gender = args[:audience_gender] if args.key?(:audience_gender)
  @budget = args[:budget] if args.key?(:budget)
  @client_billing_code = args[:client_billing_code] if args.key?(:client_billing_code)
  @client_name = args[:client_name] if args.key?(:client_name)
  @end_date = args[:end_date] if args.key?(:end_date)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_info = args[:last_modified_info] if args.key?(:last_modified_info)
  @name = args[:name] if args.key?(:name)
  @overview = args[:overview] if args.key?(:overview)
  @start_date = args[:start_date] if args.key?(:start_date)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
  @target_clicks = args[:target_clicks] if args.key?(:target_clicks)
  @target_conversions = args[:target_conversions] if args.key?(:target_conversions)
  @target_cpa_nanos = args[:target_cpa_nanos] if args.key?(:target_cpa_nanos)
  @target_cpc_nanos = args[:target_cpc_nanos] if args.key?(:target_cpc_nanos)
  @target_cpm_active_view_nanos = args[:target_cpm_active_view_nanos] if args.key?(:target_cpm_active_view_nanos)
  @target_cpm_nanos = args[:target_cpm_nanos] if args.key?(:target_cpm_nanos)
  @target_impressions = args[:target_impressions] if args.key?(:target_impressions)
end