Class: Google::Apis::DfareportingV3_4::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Represents a Report resource.

Defined Under Namespace

Classes: Criteria, CrossDimensionReachCriteria, Delivery, FloodlightCriteria, PathAttributionCriteria, PathCriteria, PathToConversionCriteria, ReachCriteria, Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



10504
10505
10506
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

The account ID to which this report belongs. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


10402
10403
10404
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10402

def 
  @account_id
end

#criteriaGoogle::Apis::DfareportingV3_4::Report::Criteria

The report criteria for a report of type "STANDARD". Corresponds to the JSON property criteria



10407
10408
10409
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10407

def criteria
  @criteria
end

#cross_dimension_reach_criteriaGoogle::Apis::DfareportingV3_4::Report::CrossDimensionReachCriteria

The report criteria for a report of type "CROSS_DIMENSION_REACH". Corresponds to the JSON property crossDimensionReachCriteria



10412
10413
10414
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10412

def cross_dimension_reach_criteria
  @cross_dimension_reach_criteria
end

#deliveryGoogle::Apis::DfareportingV3_4::Report::Delivery

The report's email delivery settings. Corresponds to the JSON property delivery



10417
10418
10419
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10417

def delivery
  @delivery
end

#etagString

The eTag of this response for caching purposes. Corresponds to the JSON property etag

Returns:

  • (String)


10422
10423
10424
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10422

def etag
  @etag
end

#file_nameString

The filename used when generating report files for this report. Corresponds to the JSON property fileName

Returns:

  • (String)


10427
10428
10429
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10427

def file_name
  @file_name
end

#floodlight_criteriaGoogle::Apis::DfareportingV3_4::Report::FloodlightCriteria

The report criteria for a report of type "FLOODLIGHT". Corresponds to the JSON property floodlightCriteria



10432
10433
10434
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10432

def floodlight_criteria
  @floodlight_criteria
end

#formatString

The output format of the report. If not specified, default format is "CSV". Note that the actual format in the completed report file might differ if for instance the report's size exceeds the format's capabilities. "CSV" will then be the fallback format. Corresponds to the JSON property format

Returns:

  • (String)


10440
10441
10442
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10440

def format
  @format
end

#idFixnum

The unique ID identifying this report resource. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10445
10446
10447
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10445

def id
  @id
end

#kindString

The kind of resource this is, in this case dfareporting#report. Corresponds to the JSON property kind

Returns:

  • (String)


10450
10451
10452
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10450

def kind
  @kind
end

#last_modified_timeFixnum

The timestamp (in milliseconds since epoch) of when this report was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (Fixnum)


10456
10457
10458
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10456

def last_modified_time
  @last_modified_time
end

#nameString

The name of the report. Corresponds to the JSON property name

Returns:

  • (String)


10461
10462
10463
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10461

def name
  @name
end

#owner_profile_idFixnum

The user profile id of the owner of this report. Corresponds to the JSON property ownerProfileId

Returns:

  • (Fixnum)


10466
10467
10468
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10466

def owner_profile_id
  @owner_profile_id
end

#path_attribution_criteriaGoogle::Apis::DfareportingV3_4::Report::PathAttributionCriteria

The report criteria for a report of type "PATH_ATTRIBUTION". Corresponds to the JSON property pathAttributionCriteria



10471
10472
10473
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10471

def path_attribution_criteria
  @path_attribution_criteria
end

#path_criteriaGoogle::Apis::DfareportingV3_4::Report::PathCriteria

The report criteria for a report of type "PATH". Corresponds to the JSON property pathCriteria



10476
10477
10478
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10476

def path_criteria
  @path_criteria
end

#path_to_conversion_criteriaGoogle::Apis::DfareportingV3_4::Report::PathToConversionCriteria

The report criteria for a report of type "PATH_TO_CONVERSION". Corresponds to the JSON property pathToConversionCriteria



10481
10482
10483
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10481

def path_to_conversion_criteria
  @path_to_conversion_criteria
end

#reach_criteriaGoogle::Apis::DfareportingV3_4::Report::ReachCriteria

The report criteria for a report of type "REACH". Corresponds to the JSON property reachCriteria



10486
10487
10488
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10486

def reach_criteria
  @reach_criteria
end

#scheduleGoogle::Apis::DfareportingV3_4::Report::Schedule

The report's schedule. Can only be set if the report's 'dateRange' is a relative date range and the relative date range is not "TODAY". Corresponds to the JSON property schedule



10492
10493
10494
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10492

def schedule
  @schedule
end

#sub_account_idFixnum

The subaccount ID to which this report belongs if applicable. Corresponds to the JSON property subAccountId

Returns:

  • (Fixnum)


10497
10498
10499
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10497

def 
  @sub_account_id
end

#typeString

The type of the report. Corresponds to the JSON property type

Returns:

  • (String)


10502
10503
10504
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10502

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
10530
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 10509

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @criteria = args[:criteria] if args.key?(:criteria)
  @cross_dimension_reach_criteria = args[:cross_dimension_reach_criteria] if args.key?(:cross_dimension_reach_criteria)
  @delivery = args[:delivery] if args.key?(:delivery)
  @etag = args[:etag] if args.key?(:etag)
  @file_name = args[:file_name] if args.key?(:file_name)
  @floodlight_criteria = args[:floodlight_criteria] if args.key?(:floodlight_criteria)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @owner_profile_id = args[:owner_profile_id] if args.key?(:owner_profile_id)
  @path_attribution_criteria = args[:path_attribution_criteria] if args.key?(:path_attribution_criteria)
  @path_criteria = args[:path_criteria] if args.key?(:path_criteria)
  @path_to_conversion_criteria = args[:path_to_conversion_criteria] if args.key?(:path_to_conversion_criteria)
  @reach_criteria = args[:reach_criteria] if args.key?(:reach_criteria)
  @schedule = args[:schedule] if args.key?(:schedule)
  @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id)
  @type = args[:type] if args.key?(:type)
end