Class: Google::Apis::DfareportingV3_4::TechnologyTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Technology Targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TechnologyTargeting

Returns a new instance of TechnologyTargeting.



12467
12468
12469
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browsersArray<Google::Apis::DfareportingV3_4::Browser>

Browsers that this ad targets. For each browser either set browserVersionId or dartId along with the version numbers. If both are specified, only browserVersionId will be used. The other fields are populated automatically when the ad is inserted or updated. Corresponds to the JSON property browsers



12425
12426
12427
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12425

def browsers
  @browsers
end

#connection_typesArray<Google::Apis::DfareportingV3_4::ConnectionType>

Connection types that this ad targets. For each connection type only id is required. The other fields are populated automatically when the ad is inserted or updated. Corresponds to the JSON property connectionTypes



12432
12433
12434
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12432

def connection_types
  @connection_types
end

#mobile_carriersArray<Google::Apis::DfareportingV3_4::MobileCarrier>

Mobile carriers that this ad targets. For each mobile carrier only id is required, and the other fields are populated automatically when the ad is inserted or updated. If targeting a mobile carrier, do not set targeting for any zip codes. Corresponds to the JSON property mobileCarriers



12440
12441
12442
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12440

def mobile_carriers
  @mobile_carriers
end

#operating_system_versionsArray<Google::Apis::DfareportingV3_4::OperatingSystemVersion>

Operating system versions that this ad targets. To target all versions, use operatingSystems. For each operating system version, only id is required. The other fields are populated automatically when the ad is inserted or updated. If targeting an operating system version, do not set targeting for the corresponding operating system in operatingSystems. Corresponds to the JSON property operatingSystemVersions



12449
12450
12451
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12449

def operating_system_versions
  @operating_system_versions
end

#operating_systemsArray<Google::Apis::DfareportingV3_4::OperatingSystem>

Operating systems that this ad targets. To target specific versions, use operatingSystemVersions. For each operating system only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting an operating system, do not set targeting for operating system versions for the same operating system. Corresponds to the JSON property operatingSystems



12458
12459
12460
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12458

def operating_systems
  @operating_systems
end

#platform_typesArray<Google::Apis::DfareportingV3_4::PlatformType>

Platform types that this ad targets. For example, desktop, mobile, or tablet. For each platform type, only id is required, and the other fields are populated automatically when the ad is inserted or updated. Corresponds to the JSON property platformTypes



12465
12466
12467
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12465

def platform_types
  @platform_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12472
12473
12474
12475
12476
12477
12478
12479
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12472

def update!(**args)
  @browsers = args[:browsers] if args.key?(:browsers)
  @connection_types = args[:connection_types] if args.key?(:connection_types)
  @mobile_carriers = args[:mobile_carriers] if args.key?(:mobile_carriers)
  @operating_system_versions = args[:operating_system_versions] if args.key?(:operating_system_versions)
  @operating_systems = args[:operating_systems] if args.key?(:operating_systems)
  @platform_types = args[:platform_types] if args.key?(:platform_types)
end