Class: Google::Apis::DfareportingV3_4::TranscodeSetting
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::TranscodeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Transcode Settings
Instance Attribute Summary collapse
-
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement.
-
#kind ⇒ String
Identifies what kind of resource this is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranscodeSetting
constructor
A new instance of TranscodeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranscodeSetting
Returns a new instance of TranscodeSetting.
12549 12550 12551 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_video_formats ⇒ Array<Fixnum>
Allowlist of video formats to be served to this placement. Set this list to
null or empty to serve all video formats.
Corresponds to the JSON property enabledVideoFormats
12541 12542 12543 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12541 def enabled_video_formats @enabled_video_formats end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#transcodeSetting".
Corresponds to the JSON property kind
12547 12548 12549 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12547 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12554 12555 12556 12557 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12554 def update!(**args) @enabled_video_formats = args[:enabled_video_formats] if args.key?(:enabled_video_formats) @kind = args[:kind] if args.key?(:kind) end |