Class: Google::Apis::DfareportingV3_4::UserRole

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb

Overview

Contains properties of auser role, which is used to manage user access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserRole

Returns a new instance of UserRole.



12771
12772
12773
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idFixnum

Account ID of this user role. This is a read-only field that can be left blank. Corresponds to the JSON property accountId

Returns:

  • (Fixnum)


12724
12725
12726
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12724

def 
  @account_id
end

#default_user_roleBoolean Also known as: default_user_role?

Whether this is a default user role. Default user roles are created by the system for the account/subaccount and cannot be modified or deleted. Each default user role comes with a basic set of preassigned permissions. Corresponds to the JSON property defaultUserRole

Returns:

  • (Boolean)


12731
12732
12733
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12731

def default_user_role
  @default_user_role
end

#idFixnum

ID of this user role. This is a read-only, auto-generated field. Corresponds to the JSON property id

Returns:

  • (Fixnum)


12737
12738
12739
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12737

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#userRole". Corresponds to the JSON property kind

Returns:

  • (String)


12743
12744
12745
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12743

def kind
  @kind
end

#nameString

Name of this user role. This is a required field. Must be less than 256 characters long. If this user role is under a subaccount, the name must be unique among sites of the same subaccount. Otherwise, this user role is a top- level user role, and the name must be unique among top-level user roles of the same account. Corresponds to the JSON property name

Returns:

  • (String)


12752
12753
12754
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12752

def name
  @name
end

#parent_user_role_idFixnum

ID of the user role that this user role is based on or copied from. This is a required field. Corresponds to the JSON property parentUserRoleId

Returns:

  • (Fixnum)


12758
12759
12760
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12758

def parent_user_role_id
  @parent_user_role_id
end

#permissionsArray<Google::Apis::DfareportingV3_4::UserRolePermission>

List of permissions associated with this user role. Corresponds to the JSON property permissions



12763
12764
12765
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12763

def permissions
  @permissions
end

#subaccount_idFixnum

Subaccount ID of this user role. This is a read-only field that can be left blank. Corresponds to the JSON property subaccountId

Returns:

  • (Fixnum)


12769
12770
12771
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12769

def subaccount_id
  @subaccount_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12776
12777
12778
12779
12780
12781
12782
12783
12784
12785
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12776

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @default_user_role = args[:default_user_role] if args.key?(:default_user_role)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @parent_user_role_id = args[:parent_user_role_id] if args.key?(:parent_user_role_id)
  @permissions = args[:permissions] if args.key?(:permissions)
  @subaccount_id = args[:subaccount_id] if args.key?(:subaccount_id)
end