Class: Google::Apis::DfareportingV3_4::VideoFormat
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::VideoFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Contains information about supported video formats.
Instance Attribute Summary collapse
-
#file_type ⇒ String
File type of the video format.
-
#id ⇒ Fixnum
ID of the video format.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#resolution ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFormat
constructor
A new instance of VideoFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFormat
Returns a new instance of VideoFormat.
12978 12979 12980 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_type ⇒ String
File type of the video format.
Corresponds to the JSON property fileType
12955 12956 12957 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12955 def file_type @file_type end |
#id ⇒ Fixnum
ID of the video format.
Corresponds to the JSON property id
12960 12961 12962 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12960 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#videoFormat".
Corresponds to the JSON property kind
12966 12967 12968 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12966 def kind @kind end |
#resolution ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property resolution
12971 12972 12973 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12971 def resolution @resolution end |
#target_bit_rate ⇒ Fixnum
The target bit rate of this video format.
Corresponds to the JSON property targetBitRate
12976 12977 12978 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12976 def target_bit_rate @target_bit_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12983 12984 12985 12986 12987 12988 12989 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 12983 def update!(**args) @file_type = args[:file_type] if args.key?(:file_type) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @resolution = args[:resolution] if args.key?(:resolution) @target_bit_rate = args[:target_bit_rate] if args.key?(:target_bit_rate) end |