Class: Google::Apis::DfareportingV3_4::CreativeAsset
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV3_4::CreativeAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dfareporting_v3_4/classes.rb,
lib/google/apis/dfareporting_v3_4/representations.rb,
lib/google/apis/dfareporting_v3_4/representations.rb
Overview
Creative Asset.
Instance Attribute Summary collapse
-
#action_script3 ⇒ Boolean
(also: #action_script3?)
Whether ActionScript3 is enabled for the flash asset.
-
#active ⇒ Boolean
(also: #active?)
Whether the video or audio asset is active.
-
#additional_sizes ⇒ Array<Google::Apis::DfareportingV3_4::Size>
Additional sizes associated with this creative asset.
-
#alignment ⇒ String
Possible alignments for an asset.
-
#artwork_type ⇒ String
Artwork type of rich media creative.
-
#asset_identifier ⇒ Google::Apis::DfareportingV3_4::CreativeAssetId
Creative Asset ID.
-
#audio_bit_rate ⇒ Fixnum
Audio stream bit rate in kbps.
-
#audio_sample_rate ⇒ Fixnum
Audio sample bit rate in hertz.
-
#backup_image_exit ⇒ Google::Apis::DfareportingV3_4::CreativeCustomEvent
Creative Custom Event.
-
#bit_rate ⇒ Fixnum
Detected bit-rate for audio or video asset.
-
#child_asset_type ⇒ String
Rich media child asset type.
-
#collapsed_size ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#companion_creative_ids ⇒ Array<Fixnum>
List of companion creatives assigned to an in-stream video creative asset.
-
#custom_start_time_value ⇒ Fixnum
Custom start time in seconds for making the asset visible.
-
#detected_features ⇒ Array<String>
List of feature dependencies for the creative asset that are detected by Campaign Manager.
-
#display_type ⇒ String
Type of rich media asset.
-
#duration ⇒ Fixnum
Duration in seconds for which an asset will be displayed.
-
#duration_type ⇒ String
Duration type for which an asset will be displayed.
-
#expanded_dimension ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#file_size ⇒ Fixnum
File size associated with this creative asset.
-
#flash_version ⇒ Fixnum
Flash version of the asset.
-
#frame_rate ⇒ Float
Video frame rate for video asset in frames per second.
-
#hide_flash_objects ⇒ Boolean
(also: #hide_flash_objects?)
Whether to hide Flash objects flag for an asset.
-
#hide_selection_boxes ⇒ Boolean
(also: #hide_selection_boxes?)
Whether to hide selection boxes flag for an asset.
-
#horizontally_locked ⇒ Boolean
(also: #horizontally_locked?)
Whether the asset is horizontally locked.
-
#id ⇒ Fixnum
Numeric ID of this creative asset.
-
#id_dimension_value ⇒ Google::Apis::DfareportingV3_4::DimensionValue
Represents a DimensionValue resource.
-
#media_duration ⇒ Float
Detected duration for audio or video asset.
-
#mime_type ⇒ String
Detected MIME type for audio or video asset.
-
#offset ⇒ Google::Apis::DfareportingV3_4::OffsetPosition
Offset Position.
-
#orientation ⇒ String
Orientation of video asset.
-
#original_backup ⇒ Boolean
(also: #original_backup?)
Whether the backup asset is original or changed by the user in Campaign Manager.
-
#polite_load ⇒ Boolean
(also: #polite_load?)
Whether this asset is used as a polite load asset.
-
#position ⇒ Google::Apis::DfareportingV3_4::OffsetPosition
Offset Position.
-
#position_left_unit ⇒ String
Offset left unit for an asset.
-
#position_top_unit ⇒ String
Offset top unit for an asset.
-
#progressive_serving_url ⇒ String
Progressive URL for video asset.
-
#pushdown ⇒ Boolean
(also: #pushdown?)
Whether the asset pushes down other content.
-
#pushdown_duration ⇒ Float
Pushdown duration in seconds for an asset.
-
#role ⇒ String
Role of the asset in relation to creative.
-
#size ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
-
#ssl_compliant ⇒ Boolean
(also: #ssl_compliant?)
Whether the asset is SSL-compliant.
-
#start_time_type ⇒ String
Initial wait time type before making the asset visible.
-
#streaming_serving_url ⇒ String
Streaming URL for video asset.
-
#transparency ⇒ Boolean
(also: #transparency?)
Whether the asset is transparent.
-
#vertically_locked ⇒ Boolean
(also: #vertically_locked?)
Whether the asset is vertically locked.
-
#window_mode ⇒ String
Window mode options for flash assets.
-
#z_index ⇒ Fixnum
zIndex value of an asset.
-
#zip_filename ⇒ String
File name of zip file.
-
#zip_filesize ⇒ String
Size of zip file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeAsset
constructor
A new instance of CreativeAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeAsset
Returns a new instance of CreativeAsset.
3737 3738 3739 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_script3 ⇒ Boolean Also known as: action_script3?
Whether ActionScript3 is enabled for the flash asset. This is a read-only
field. Applicable to the following creative type: FLASH_INPAGE. Applicable to
DISPLAY when the primary asset type is not HTML_IMAGE.
Corresponds to the JSON property actionScript3
3391 3392 3393 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3391 def action_script3 @action_script3 end |
#active ⇒ Boolean Also known as: active?
Whether the video or audio asset is active. This is a read-only field for
VPAID_NON_LINEAR_VIDEO assets. Applicable to the following creative types:
INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID.
Corresponds to the JSON property active
3399 3400 3401 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3399 def active @active end |
#additional_sizes ⇒ Array<Google::Apis::DfareportingV3_4::Size>
Additional sizes associated with this creative asset. HTML5 asset generated by
compatible software such as GWD will be able to support more sizes this
creative asset can render.
Corresponds to the JSON property additionalSizes
3407 3408 3409 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3407 def additional_sizes @additional_sizes end |
#alignment ⇒ String
Possible alignments for an asset. This is a read-only field. Applicable to the
following creative types: RICH_MEDIA_DISPLAY_MULTI_FLOATING_INTERSTITIAL .
Corresponds to the JSON property alignment
3413 3414 3415 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3413 def alignment @alignment end |
#artwork_type ⇒ String
Artwork type of rich media creative. This is a read-only field. Applicable to
the following creative types: all RICH_MEDIA.
Corresponds to the JSON property artworkType
3419 3420 3421 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3419 def artwork_type @artwork_type end |
#asset_identifier ⇒ Google::Apis::DfareportingV3_4::CreativeAssetId
Creative Asset ID.
Corresponds to the JSON property assetIdentifier
3424 3425 3426 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3424 def asset_identifier @asset_identifier end |
#audio_bit_rate ⇒ Fixnum
Audio stream bit rate in kbps. This is a read-only field. Applicable to the
following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID.
Corresponds to the JSON property audioBitRate
3430 3431 3432 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3430 def audio_bit_rate @audio_bit_rate end |
#audio_sample_rate ⇒ Fixnum
Audio sample bit rate in hertz. This is a read-only field. Applicable to the
following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and all VPAID.
Corresponds to the JSON property audioSampleRate
3436 3437 3438 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3436 def audio_sample_rate @audio_sample_rate end |
#backup_image_exit ⇒ Google::Apis::DfareportingV3_4::CreativeCustomEvent
Creative Custom Event.
Corresponds to the JSON property backupImageExit
3441 3442 3443 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3441 def backup_image_exit @backup_image_exit end |
#bit_rate ⇒ Fixnum
Detected bit-rate for audio or video asset. This is a read-only field.
Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and
all VPAID.
Corresponds to the JSON property bitRate
3448 3449 3450 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3448 def bit_rate @bit_rate end |
#child_asset_type ⇒ String
Rich media child asset type. This is a read-only field. Applicable to the
following creative types: all VPAID.
Corresponds to the JSON property childAssetType
3454 3455 3456 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3454 def child_asset_type @child_asset_type end |
#collapsed_size ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property collapsedSize
3459 3460 3461 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3459 def collapsed_size @collapsed_size end |
#companion_creative_ids ⇒ Array<Fixnum>
List of companion creatives assigned to an in-stream video creative asset.
Acceptable values include IDs of existing flash and image creatives.
Applicable to INSTREAM_VIDEO creative type with dynamicAssetSelection set to
true.
Corresponds to the JSON property companionCreativeIds
3467 3468 3469 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3467 def companion_creative_ids @companion_creative_ids end |
#custom_start_time_value ⇒ Fixnum
Custom start time in seconds for making the asset visible. Applicable to the
following creative types: all RICH_MEDIA. Value must be greater than or equal
to 0.
Corresponds to the JSON property customStartTimeValue
3474 3475 3476 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3474 def custom_start_time_value @custom_start_time_value end |
#detected_features ⇒ Array<String>
List of feature dependencies for the creative asset that are detected by
Campaign Manager. Feature dependencies are features that a browser must be
able to support in order to render your HTML5 creative correctly. This is a
read-only, auto-generated field. Applicable to the following creative types:
HTML5_BANNER. Applicable to DISPLAY when the primary asset type is not
HTML_IMAGE.
Corresponds to the JSON property detectedFeatures
3484 3485 3486 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3484 def detected_features @detected_features end |
#display_type ⇒ String
Type of rich media asset. This is a read-only field. Applicable to the
following creative types: all RICH_MEDIA.
Corresponds to the JSON property displayType
3490 3491 3492 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3490 def display_type @display_type end |
#duration ⇒ Fixnum
Duration in seconds for which an asset will be displayed. Applicable to the
following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and
VPAID_LINEAR_VIDEO. Value must be greater than or equal to 1.
Corresponds to the JSON property duration
3497 3498 3499 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3497 def duration @duration end |
#duration_type ⇒ String
Duration type for which an asset will be displayed. Applicable to the
following creative types: all RICH_MEDIA.
Corresponds to the JSON property durationType
3503 3504 3505 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3503 def duration_type @duration_type end |
#expanded_dimension ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property expandedDimension
3508 3509 3510 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3508 def @expanded_dimension end |
#file_size ⇒ Fixnum
File size associated with this creative asset. This is a read-only field.
Applicable to all but the following creative types: all REDIRECT and
TRACKING_TEXT.
Corresponds to the JSON property fileSize
3515 3516 3517 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3515 def file_size @file_size end |
#flash_version ⇒ Fixnum
Flash version of the asset. This is a read-only field. Applicable to the
following creative types: FLASH_INPAGE, all RICH_MEDIA, and all VPAID.
Applicable to DISPLAY when the primary asset type is not HTML_IMAGE.
Corresponds to the JSON property flashVersion
3522 3523 3524 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3522 def flash_version @flash_version end |
#frame_rate ⇒ Float
Video frame rate for video asset in frames per second. This is a read-only
field. Applicable to the following creative types: INSTREAM_VIDEO and all
VPAID.
Corresponds to the JSON property frameRate
3529 3530 3531 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3529 def frame_rate @frame_rate end |
#hide_flash_objects ⇒ Boolean Also known as: hide_flash_objects?
Whether to hide Flash objects flag for an asset. Applicable to the following
creative types: all RICH_MEDIA.
Corresponds to the JSON property hideFlashObjects
3535 3536 3537 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3535 def hide_flash_objects @hide_flash_objects end |
#hide_selection_boxes ⇒ Boolean Also known as: hide_selection_boxes?
Whether to hide selection boxes flag for an asset. Applicable to the following
creative types: all RICH_MEDIA.
Corresponds to the JSON property hideSelectionBoxes
3542 3543 3544 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3542 def hide_selection_boxes @hide_selection_boxes end |
#horizontally_locked ⇒ Boolean Also known as: horizontally_locked?
Whether the asset is horizontally locked. This is a read-only field.
Applicable to the following creative types: all RICH_MEDIA.
Corresponds to the JSON property horizontallyLocked
3549 3550 3551 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3549 def horizontally_locked @horizontally_locked end |
#id ⇒ Fixnum
Numeric ID of this creative asset. This is a required field and should not be
modified. Applicable to all but the following creative types: all REDIRECT and
TRACKING_TEXT.
Corresponds to the JSON property id
3557 3558 3559 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3557 def id @id end |
#id_dimension_value ⇒ Google::Apis::DfareportingV3_4::DimensionValue
Represents a DimensionValue resource.
Corresponds to the JSON property idDimensionValue
3562 3563 3564 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3562 def id_dimension_value @id_dimension_value end |
#media_duration ⇒ Float
Detected duration for audio or video asset. This is a read-only field.
Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and
all VPAID.
Corresponds to the JSON property mediaDuration
3569 3570 3571 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3569 def media_duration @media_duration end |
#mime_type ⇒ String
Detected MIME type for audio or video asset. This is a read-only field.
Applicable to the following creative types: INSTREAM_AUDIO, INSTREAM_VIDEO and
all VPAID.
Corresponds to the JSON property mimeType
3576 3577 3578 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3576 def mime_type @mime_type end |
#offset ⇒ Google::Apis::DfareportingV3_4::OffsetPosition
Offset Position.
Corresponds to the JSON property offset
3581 3582 3583 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3581 def offset @offset end |
#orientation ⇒ String
Orientation of video asset. This is a read-only, auto-generated field.
Corresponds to the JSON property orientation
3586 3587 3588 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3586 def orientation @orientation end |
#original_backup ⇒ Boolean Also known as: original_backup?
Whether the backup asset is original or changed by the user in Campaign
Manager. Applicable to the following creative types: all RICH_MEDIA.
Corresponds to the JSON property originalBackup
3592 3593 3594 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3592 def original_backup @original_backup end |
#polite_load ⇒ Boolean Also known as: polite_load?
Whether this asset is used as a polite load asset.
Corresponds to the JSON property politeLoad
3598 3599 3600 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3598 def polite_load @polite_load end |
#position ⇒ Google::Apis::DfareportingV3_4::OffsetPosition
Offset Position.
Corresponds to the JSON property position
3604 3605 3606 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3604 def position @position end |
#position_left_unit ⇒ String
Offset left unit for an asset. This is a read-only field. Applicable to the
following creative types: all RICH_MEDIA.
Corresponds to the JSON property positionLeftUnit
3610 3611 3612 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3610 def position_left_unit @position_left_unit end |
#position_top_unit ⇒ String
Offset top unit for an asset. This is a read-only field if the asset
displayType is ASSET_DISPLAY_TYPE_OVERLAY. Applicable to the following
creative types: all RICH_MEDIA.
Corresponds to the JSON property positionTopUnit
3617 3618 3619 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3617 def position_top_unit @position_top_unit end |
#progressive_serving_url ⇒ String
Progressive URL for video asset. This is a read-only field. Applicable to the
following creative types: INSTREAM_VIDEO and all VPAID.
Corresponds to the JSON property progressiveServingUrl
3623 3624 3625 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3623 def progressive_serving_url @progressive_serving_url end |
#pushdown ⇒ Boolean Also known as: pushdown?
Whether the asset pushes down other content. Applicable to the following
creative types: all RICH_MEDIA. Additionally, only applicable when the asset
offsets are 0, the collapsedSize.width matches size.width, and the
collapsedSize.height is less than size.height.
Corresponds to the JSON property pushdown
3631 3632 3633 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3631 def pushdown @pushdown end |
#pushdown_duration ⇒ Float
Pushdown duration in seconds for an asset. Applicable to the following
creative types: all RICH_MEDIA.Additionally, only applicable when the asset
pushdown field is true, the offsets are 0, the collapsedSize.width matches
size.width, and the collapsedSize.height is less than size.height. Acceptable
values are 0 to 9.99, inclusive.
Corresponds to the JSON property pushdownDuration
3641 3642 3643 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3641 def pushdown_duration @pushdown_duration end |
#role ⇒ String
Role of the asset in relation to creative. Applicable to all but the following
creative types: all REDIRECT and TRACKING_TEXT. This is a required field.
PRIMARY applies to DISPLAY, FLASH_INPAGE, HTML5_BANNER, IMAGE,
DISPLAY_IMAGE_GALLERY, all RICH_MEDIA (which may contain multiple primary
assets), and all VPAID creatives. BACKUP_IMAGE applies to FLASH_INPAGE,
HTML5_BANNER, all RICH_MEDIA, and all VPAID creatives. Applicable to DISPLAY
when the primary asset type is not HTML_IMAGE. ADDITIONAL_IMAGE and
ADDITIONAL_FLASH apply to FLASH_INPAGE creatives. OTHER refers to assets from
sources other than Campaign Manager, such as Studio uploaded assets,
applicable to all RICH_MEDIA and all VPAID creatives. PARENT_VIDEO refers to
videos uploaded by the user in Campaign Manager and is applicable to
INSTREAM_VIDEO and VPAID_LINEAR_VIDEO creatives. TRANSCODED_VIDEO refers to
videos transcoded by Campaign Manager from PARENT_VIDEO assets and is
applicable to INSTREAM_VIDEO and VPAID_LINEAR_VIDEO creatives. ALTERNATE_VIDEO
refers to the Campaign Manager representation of child asset videos from
Studio, and is applicable to VPAID_LINEAR_VIDEO creatives. These cannot be
added or removed within Campaign Manager. For VPAID_LINEAR_VIDEO creatives,
PARENT_VIDEO, TRANSCODED_VIDEO and ALTERNATE_VIDEO assets that are marked
active serve as backup in case the VPAID creative cannot be served. Only
PARENT_VIDEO assets can be added or removed for an INSTREAM_VIDEO or
VPAID_LINEAR_VIDEO creative. PARENT_AUDIO refers to audios uploaded by the
user in Campaign Manager and is applicable to INSTREAM_AUDIO creatives.
TRANSCODED_AUDIO refers to audios transcoded by Campaign Manager from
PARENT_AUDIO assets and is applicable to INSTREAM_AUDIO creatives.
Corresponds to the JSON property role
3669 3670 3671 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3669 def role @role end |
#size ⇒ Google::Apis::DfareportingV3_4::Size
Represents the dimensions of ads, placements, creatives, or creative assets.
Corresponds to the JSON property size
3674 3675 3676 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3674 def size @size end |
#ssl_compliant ⇒ Boolean Also known as: ssl_compliant?
Whether the asset is SSL-compliant. This is a read-only field. Applicable to
all but the following creative types: all REDIRECT and TRACKING_TEXT.
Corresponds to the JSON property sslCompliant
3680 3681 3682 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3680 def ssl_compliant @ssl_compliant end |
#start_time_type ⇒ String
Initial wait time type before making the asset visible. Applicable to the
following creative types: all RICH_MEDIA.
Corresponds to the JSON property startTimeType
3687 3688 3689 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3687 def start_time_type @start_time_type end |
#streaming_serving_url ⇒ String
Streaming URL for video asset. This is a read-only field. Applicable to the
following creative types: INSTREAM_VIDEO and all VPAID.
Corresponds to the JSON property streamingServingUrl
3693 3694 3695 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3693 def streaming_serving_url @streaming_serving_url end |
#transparency ⇒ Boolean Also known as: transparency?
Whether the asset is transparent. Applicable to the following creative types:
all RICH_MEDIA. Additionally, only applicable to HTML5 assets.
Corresponds to the JSON property transparency
3699 3700 3701 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3699 def transparency @transparency end |
#vertically_locked ⇒ Boolean Also known as: vertically_locked?
Whether the asset is vertically locked. This is a read-only field. Applicable
to the following creative types: all RICH_MEDIA.
Corresponds to the JSON property verticallyLocked
3706 3707 3708 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3706 def vertically_locked @vertically_locked end |
#window_mode ⇒ String
Window mode options for flash assets. Applicable to the following creative
types: FLASH_INPAGE, RICH_MEDIA_DISPLAY_EXPANDING, RICH_MEDIA_IM_EXPAND,
RICH_MEDIA_DISPLAY_BANNER, and RICH_MEDIA_INPAGE_FLOATING.
Corresponds to the JSON property windowMode
3714 3715 3716 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3714 def window_mode @window_mode end |
#z_index ⇒ Fixnum
zIndex value of an asset. Applicable to the following creative types: all
RICH_MEDIA.Additionally, only applicable to assets whose displayType is NOT
one of the following types: ASSET_DISPLAY_TYPE_INPAGE or
ASSET_DISPLAY_TYPE_OVERLAY. Acceptable values are -999999999 to 999999999,
inclusive.
Corresponds to the JSON property zIndex
3723 3724 3725 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3723 def z_index @z_index end |
#zip_filename ⇒ String
File name of zip file. This is a read-only field. Applicable to the following
creative types: HTML5_BANNER.
Corresponds to the JSON property zipFilename
3729 3730 3731 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3729 def zip_filename @zip_filename end |
#zip_filesize ⇒ String
Size of zip file. This is a read-only field. Applicable to the following
creative types: HTML5_BANNER.
Corresponds to the JSON property zipFilesize
3735 3736 3737 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3735 def zip_filesize @zip_filesize end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3742 3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 |
# File 'lib/google/apis/dfareporting_v3_4/classes.rb', line 3742 def update!(**args) @action_script3 = args[:action_script3] if args.key?(:action_script3) @active = args[:active] if args.key?(:active) @additional_sizes = args[:additional_sizes] if args.key?(:additional_sizes) @alignment = args[:alignment] if args.key?(:alignment) @artwork_type = args[:artwork_type] if args.key?(:artwork_type) @asset_identifier = args[:asset_identifier] if args.key?(:asset_identifier) @audio_bit_rate = args[:audio_bit_rate] if args.key?(:audio_bit_rate) @audio_sample_rate = args[:audio_sample_rate] if args.key?(:audio_sample_rate) @backup_image_exit = args[:backup_image_exit] if args.key?(:backup_image_exit) @bit_rate = args[:bit_rate] if args.key?(:bit_rate) @child_asset_type = args[:child_asset_type] if args.key?(:child_asset_type) @collapsed_size = args[:collapsed_size] if args.key?(:collapsed_size) @companion_creative_ids = args[:companion_creative_ids] if args.key?(:companion_creative_ids) @custom_start_time_value = args[:custom_start_time_value] if args.key?(:custom_start_time_value) @detected_features = args[:detected_features] if args.key?(:detected_features) @display_type = args[:display_type] if args.key?(:display_type) @duration = args[:duration] if args.key?(:duration) @duration_type = args[:duration_type] if args.key?(:duration_type) @expanded_dimension = args[:expanded_dimension] if args.key?(:expanded_dimension) @file_size = args[:file_size] if args.key?(:file_size) @flash_version = args[:flash_version] if args.key?(:flash_version) @frame_rate = args[:frame_rate] if args.key?(:frame_rate) @hide_flash_objects = args[:hide_flash_objects] if args.key?(:hide_flash_objects) @hide_selection_boxes = args[:hide_selection_boxes] if args.key?(:hide_selection_boxes) @horizontally_locked = args[:horizontally_locked] if args.key?(:horizontally_locked) @id = args[:id] if args.key?(:id) @id_dimension_value = args[:id_dimension_value] if args.key?(:id_dimension_value) @media_duration = args[:media_duration] if args.key?(:media_duration) @mime_type = args[:mime_type] if args.key?(:mime_type) @offset = args[:offset] if args.key?(:offset) @orientation = args[:orientation] if args.key?(:orientation) @original_backup = args[:original_backup] if args.key?(:original_backup) @polite_load = args[:polite_load] if args.key?(:polite_load) @position = args[:position] if args.key?(:position) @position_left_unit = args[:position_left_unit] if args.key?(:position_left_unit) @position_top_unit = args[:position_top_unit] if args.key?(:position_top_unit) @progressive_serving_url = args[:progressive_serving_url] if args.key?(:progressive_serving_url) @pushdown = args[:pushdown] if args.key?(:pushdown) @pushdown_duration = args[:pushdown_duration] if args.key?(:pushdown_duration) @role = args[:role] if args.key?(:role) @size = args[:size] if args.key?(:size) @ssl_compliant = args[:ssl_compliant] if args.key?(:ssl_compliant) @start_time_type = args[:start_time_type] if args.key?(:start_time_type) @streaming_serving_url = args[:streaming_serving_url] if args.key?(:streaming_serving_url) @transparency = args[:transparency] if args.key?(:transparency) @vertically_locked = args[:vertically_locked] if args.key?(:vertically_locked) @window_mode = args[:window_mode] if args.key?(:window_mode) @z_index = args[:z_index] if args.key?(:z_index) @zip_filename = args[:zip_filename] if args.key?(:zip_filename) @zip_filesize = args[:zip_filesize] if args.key?(:zip_filesize) end |